# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hedgehog/protocol/proto/analog.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='hedgehog/protocol/proto/analog.proto',
  package='hedgehog.protocol.proto',
  syntax='proto3',
  serialized_pb=_b('\n$hedgehog/protocol/proto/analog.proto\x12\x17hedgehog.protocol.proto\"\x1d\n\rAnalogRequest\x12\x0c\n\x04port\x18\x01 \x01(\r\"+\n\x0c\x41nalogUpdate\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\r\"1\n\x11\x41nalogStateAction\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\x0e\n\x06pullup\x18\x02 \x01(\x08\x62\x06proto3')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_ANALOGREQUEST = _descriptor.Descriptor(
  name='AnalogRequest',
  full_name='hedgehog.protocol.proto.AnalogRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.AnalogRequest.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=94,
)


_ANALOGUPDATE = _descriptor.Descriptor(
  name='AnalogUpdate',
  full_name='hedgehog.protocol.proto.AnalogUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.AnalogUpdate.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='hedgehog.protocol.proto.AnalogUpdate.value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=139,
)


_ANALOGSTATEACTION = _descriptor.Descriptor(
  name='AnalogStateAction',
  full_name='hedgehog.protocol.proto.AnalogStateAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.AnalogStateAction.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pullup', full_name='hedgehog.protocol.proto.AnalogStateAction.pullup', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=190,
)

DESCRIPTOR.message_types_by_name['AnalogRequest'] = _ANALOGREQUEST
DESCRIPTOR.message_types_by_name['AnalogUpdate'] = _ANALOGUPDATE
DESCRIPTOR.message_types_by_name['AnalogStateAction'] = _ANALOGSTATEACTION

AnalogRequest = _reflection.GeneratedProtocolMessageType('AnalogRequest', (_message.Message,), dict(
  DESCRIPTOR = _ANALOGREQUEST,
  __module__ = 'hedgehog.protocol.proto.analog_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.AnalogRequest)
  ))
_sym_db.RegisterMessage(AnalogRequest)

AnalogUpdate = _reflection.GeneratedProtocolMessageType('AnalogUpdate', (_message.Message,), dict(
  DESCRIPTOR = _ANALOGUPDATE,
  __module__ = 'hedgehog.protocol.proto.analog_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.AnalogUpdate)
  ))
_sym_db.RegisterMessage(AnalogUpdate)

AnalogStateAction = _reflection.GeneratedProtocolMessageType('AnalogStateAction', (_message.Message,), dict(
  DESCRIPTOR = _ANALOGSTATEACTION,
  __module__ = 'hedgehog.protocol.proto.analog_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.AnalogStateAction)
  ))
_sym_db.RegisterMessage(AnalogStateAction)


# @@protoc_insertion_point(module_scope)



from typing import Union

from . import RequestMsg, ReplyMsg, Message
from hedgehog.protocol.proto import io_pb2
from hedgehog.protocol.proto.subscription_pb2 import Subscription
from hedgehog.utils import protobuf


@protobuf.message(io_pb2.DigitalMessage, 'digital_message', fields=('port',))
class Request(Message):
    def __init__(self, port: int) -> None:
        self.port = port

    def _serialize(self, msg: io_pb2.DigitalMessage) -> None:
        msg.port = self.port


@protobuf.message(io_pb2.DigitalMessage, 'digital_message', fields=('port', 'subscription'))
class Subscribe(Message):
    def __init__(self, port: int, subscription: Subscription) -> None:
        self.port = port
        self.subscription = subscription

    def _serialize(self, msg: io_pb2.DigitalMessage) -> None:
        msg.port = self.port
        msg.subscription.CopyFrom(self.subscription)


@RequestMsg.parser('digital_message')
def _parse_request(msg: io_pb2.DigitalMessage) -> Union[Request, Subscribe]:
    port = msg.port
    subscription = msg.subscription if msg.HasField('subscription') else None
    if subscription is None:
        return Request(port)
    else:
        return Subscribe(port, subscription)


@protobuf.message(io_pb2.DigitalMessage, 'digital_message', fields=('port', 'value'))
class Reply(Message):
    def __init__(self, port: int, value: bool) -> None:
        self.port = port
        self.value = value

    def _serialize(self, msg: io_pb2.DigitalMessage) -> None:
        msg.port = self.port
        msg.value = self.value


@protobuf.message(io_pb2.DigitalMessage, 'digital_message')
class Update(Message):
    async = True

    def __init__(self, port: int, value: bool, subscription: Subscription) -> None:
        self.port = port
        self.value = value
        self.subscription = subscription

    def _serialize(self, msg: io_pb2.DigitalMessage) -> None:
        msg.port = self.port
        msg.value = self.value
        msg.subscription.CopyFrom(self.subscription)


@ReplyMsg.parser('digital_message')
def _parse_reply(msg: io_pb2.DigitalMessage) -> Union[Reply, Update]:
    port = msg.port
    value = msg.value
    subscription = msg.subscription if msg.HasField('subscription') else None
    if subscription is None:
        return Reply(port, value)
    else:
        return Update(port, value, subscription)



from . import RequestMsg, ReplyMsg, SimpleMessage
from hedgehog.protocol.errors import InvalidCommandError
from hedgehog.protocol.proto import process_pb2
from hedgehog.protocol.proto.process_pb2 import STDIN, STDOUT, STDERR


@RequestMsg.message(process_pb2.ProcessExecuteAction, 'process_execute_action')
class ExecuteAction(SimpleMessage):
    def __init__(self, *args: str, working_dir: str=None) -> None:
        self.args = args
        self.working_dir = working_dir

    @classmethod
    def _parse(cls, msg: process_pb2.ProcessExecuteAction) -> 'ExecuteAction':
        args = msg.args
        working_dir = msg.working_dir if msg.working_dir != '' else None
        return cls(*args, working_dir=working_dir)

    def _serialize(self, msg: process_pb2.ProcessExecuteAction) -> None:
        msg.args.extend(self.args)
        if self.working_dir is not None:
            msg.working_dir = self.working_dir


@ReplyMsg.message(process_pb2.ProcessExecuteReply, 'process_execute_reply')
class ExecuteReply(SimpleMessage):
    def __init__(self, pid: int) -> None:
        self.pid = pid

    @classmethod
    def _parse(cls, msg: process_pb2.ProcessExecuteReply) -> 'ExecuteReply':
        pid = msg.pid
        return cls(pid)

    def _serialize(self, msg: process_pb2.ProcessExecuteReply) -> None:
        msg.pid = self.pid


@RequestMsg.message(process_pb2.ProcessStreamMessage, 'process_stream_message')
class StreamAction(SimpleMessage):
    def __init__(self, pid: int, fileno: int, chunk: bytes=b'') -> None:
        if fileno != STDIN:
            raise InvalidCommandError("only STDIN is writable")
        self.pid = pid
        self.fileno = fileno
        self.chunk = chunk

    @classmethod
    def _parse(cls, msg: process_pb2.ProcessStreamMessage) -> 'StreamAction':
        pid = msg.pid
        fileno = msg.fileno
        chunk = msg.chunk
        return cls(pid, fileno, chunk)

    def _serialize(self, msg: process_pb2.ProcessStreamMessage) -> None:
        msg.pid = self.pid
        msg.fileno = self.fileno
        msg.chunk = self.chunk


@ReplyMsg.message(process_pb2.ProcessStreamMessage, 'process_stream_message')
class StreamUpdate(SimpleMessage):
    async = True

    def __init__(self, pid: int, fileno: int, chunk: bytes=b'') -> None:
        if fileno not in (STDOUT, STDERR):
            raise InvalidCommandError("only STDOUT and STDERR are readable")
        self.pid = pid
        self.fileno = fileno
        self.chunk = chunk

    @classmethod
    def _parse(cls, msg: process_pb2.ProcessStreamMessage) -> 'StreamUpdate':
        pid = msg.pid
        fileno = msg.fileno
        chunk = msg.chunk
        return cls(pid, fileno, chunk)

    def _serialize(self, msg: process_pb2.ProcessStreamMessage) -> None:
        msg.pid = self.pid
        msg.fileno = self.fileno
        msg.chunk = self.chunk


@RequestMsg.message(process_pb2.ProcessSignalAction, 'process_signal_action')
class SignalAction(SimpleMessage):
    def __init__(self, pid: int, signal: int) -> None:
        self.pid = pid
        self.signal = signal

    @classmethod
    def _parse(cls, msg: process_pb2.ProcessSignalAction) -> 'SignalAction':
        pid = msg.pid
        signal = msg.signal
        return cls(pid, signal)

    def _serialize(self, msg: process_pb2.ProcessSignalAction) -> None:
        msg.pid = self.pid
        msg.signal = self.signal


@ReplyMsg.message(process_pb2.ProcessExitUpdate, 'process_exit_update')
class ExitUpdate(SimpleMessage):
    async = True

    def __init__(self, pid: int, exit_code: int) -> None:
        self.pid = pid
        self.exit_code = exit_code

    @classmethod
    def _parse(cls, msg: process_pb2.ProcessExitUpdate) -> 'ExitUpdate':
        pid = msg.pid
        exit_code = msg.exit_code
        return cls(pid, exit_code)

    def _serialize(self, msg: process_pb2.ProcessExitUpdate) -> None:
        msg.pid = self.pid
        msg.exit_code = self.exit_code



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hedgehog/protocol/proto/motor.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hedgehog.protocol.proto import subscription_pb2 as hedgehog_dot_protocol_dot_proto_dot_subscription__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hedgehog/protocol/proto/motor.proto',
  package='hedgehog.protocol.proto',
  syntax='proto3',
  serialized_pb=_b('\n#hedgehog/protocol/proto/motor.proto\x12\x17hedgehog.protocol.proto\x1a*hedgehog/protocol/proto/subscription.proto\"\xcf\x01\n\x0bMotorAction\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\x32\n\x05state\x18\x02 \x01(\x0e\x32#.hedgehog.protocol.proto.MotorState\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x11\x12:\n\rreached_state\x18\x04 \x01(\x0e\x32#.hedgehog.protocol.proto.MotorState\x12\x12\n\x08relative\x18\x05 \x01(\x11H\x00\x12\x12\n\x08\x61\x62solute\x18\x06 \x01(\x11H\x00\x42\n\n\x08position\"\xa4\x01\n\x13MotorCommandMessage\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\x32\n\x05state\x18\x02 \x01(\x0e\x32#.hedgehog.protocol.proto.MotorState\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x11\x12;\n\x0csubscription\x18\x04 \x01(\x0b\x32%.hedgehog.protocol.proto.Subscription\"\x82\x01\n\x11MotorStateMessage\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\x10\n\x08velocity\x18\x02 \x01(\x11\x12\x10\n\x08position\x18\x03 \x01(\x11\x12;\n\x0csubscription\x18\x04 \x01(\x0b\x32%.hedgehog.protocol.proto.Subscription\"8\n\x16MotorSetPositionAction\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\x10\n\x08position\x18\x02 \x01(\x11*0\n\nMotorState\x12\t\n\x05POWER\x10\x00\x12\t\n\x05\x42RAKE\x10\x01\x12\x0c\n\x08VELOCITY\x10\x02\x42)\n\x1f\x61t.pria.hedgehog.protocol.protoB\x06MotorPb\x06proto3')
  ,
  dependencies=[hedgehog_dot_protocol_dot_proto_dot_subscription__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_MOTORSTATE = _descriptor.EnumDescriptor(
  name='MotorState',
  full_name='hedgehog.protocol.proto.MotorState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='POWER', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BRAKE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VELOCITY', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=676,
  serialized_end=724,
)
_sym_db.RegisterEnumDescriptor(_MOTORSTATE)

MotorState = enum_type_wrapper.EnumTypeWrapper(_MOTORSTATE)
POWER = 0
BRAKE = 1
VELOCITY = 2



_MOTORACTION = _descriptor.Descriptor(
  name='MotorAction',
  full_name='hedgehog.protocol.proto.MotorAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.MotorAction.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='hedgehog.protocol.proto.MotorAction.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='hedgehog.protocol.proto.MotorAction.amount', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reached_state', full_name='hedgehog.protocol.proto.MotorAction.reached_state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='relative', full_name='hedgehog.protocol.proto.MotorAction.relative', index=4,
      number=5, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='absolute', full_name='hedgehog.protocol.proto.MotorAction.absolute', index=5,
      number=6, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='position', full_name='hedgehog.protocol.proto.MotorAction.position',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=109,
  serialized_end=316,
)


_MOTORCOMMANDMESSAGE = _descriptor.Descriptor(
  name='MotorCommandMessage',
  full_name='hedgehog.protocol.proto.MotorCommandMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.MotorCommandMessage.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='hedgehog.protocol.proto.MotorCommandMessage.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='hedgehog.protocol.proto.MotorCommandMessage.amount', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subscription', full_name='hedgehog.protocol.proto.MotorCommandMessage.subscription', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=319,
  serialized_end=483,
)


_MOTORSTATEMESSAGE = _descriptor.Descriptor(
  name='MotorStateMessage',
  full_name='hedgehog.protocol.proto.MotorStateMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.MotorStateMessage.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='hedgehog.protocol.proto.MotorStateMessage.velocity', index=1,
      number=2, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position', full_name='hedgehog.protocol.proto.MotorStateMessage.position', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subscription', full_name='hedgehog.protocol.proto.MotorStateMessage.subscription', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=486,
  serialized_end=616,
)


_MOTORSETPOSITIONACTION = _descriptor.Descriptor(
  name='MotorSetPositionAction',
  full_name='hedgehog.protocol.proto.MotorSetPositionAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.MotorSetPositionAction.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position', full_name='hedgehog.protocol.proto.MotorSetPositionAction.position', index=1,
      number=2, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=618,
  serialized_end=674,
)

_MOTORACTION.fields_by_name['state'].enum_type = _MOTORSTATE
_MOTORACTION.fields_by_name['reached_state'].enum_type = _MOTORSTATE
_MOTORACTION.oneofs_by_name['position'].fields.append(
  _MOTORACTION.fields_by_name['relative'])
_MOTORACTION.fields_by_name['relative'].containing_oneof = _MOTORACTION.oneofs_by_name['position']
_MOTORACTION.oneofs_by_name['position'].fields.append(
  _MOTORACTION.fields_by_name['absolute'])
_MOTORACTION.fields_by_name['absolute'].containing_oneof = _MOTORACTION.oneofs_by_name['position']
_MOTORCOMMANDMESSAGE.fields_by_name['state'].enum_type = _MOTORSTATE
_MOTORCOMMANDMESSAGE.fields_by_name['subscription'].message_type = hedgehog_dot_protocol_dot_proto_dot_subscription__pb2._SUBSCRIPTION
_MOTORSTATEMESSAGE.fields_by_name['subscription'].message_type = hedgehog_dot_protocol_dot_proto_dot_subscription__pb2._SUBSCRIPTION
DESCRIPTOR.message_types_by_name['MotorAction'] = _MOTORACTION
DESCRIPTOR.message_types_by_name['MotorCommandMessage'] = _MOTORCOMMANDMESSAGE
DESCRIPTOR.message_types_by_name['MotorStateMessage'] = _MOTORSTATEMESSAGE
DESCRIPTOR.message_types_by_name['MotorSetPositionAction'] = _MOTORSETPOSITIONACTION
DESCRIPTOR.enum_types_by_name['MotorState'] = _MOTORSTATE

MotorAction = _reflection.GeneratedProtocolMessageType('MotorAction', (_message.Message,), dict(
  DESCRIPTOR = _MOTORACTION,
  __module__ = 'hedgehog.protocol.proto.motor_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.MotorAction)
  ))
_sym_db.RegisterMessage(MotorAction)

MotorCommandMessage = _reflection.GeneratedProtocolMessageType('MotorCommandMessage', (_message.Message,), dict(
  DESCRIPTOR = _MOTORCOMMANDMESSAGE,
  __module__ = 'hedgehog.protocol.proto.motor_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.MotorCommandMessage)
  ))
_sym_db.RegisterMessage(MotorCommandMessage)

MotorStateMessage = _reflection.GeneratedProtocolMessageType('MotorStateMessage', (_message.Message,), dict(
  DESCRIPTOR = _MOTORSTATEMESSAGE,
  __module__ = 'hedgehog.protocol.proto.motor_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.MotorStateMessage)
  ))
_sym_db.RegisterMessage(MotorStateMessage)

MotorSetPositionAction = _reflection.GeneratedProtocolMessageType('MotorSetPositionAction', (_message.Message,), dict(
  DESCRIPTOR = _MOTORSETPOSITIONACTION,
  __module__ = 'hedgehog.protocol.proto.motor_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.MotorSetPositionAction)
  ))
_sym_db.RegisterMessage(MotorSetPositionAction)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\037at.pria.hedgehog.protocol.protoB\006MotorP'))
# @@protoc_insertion_point(module_scope)



from typing import cast

from hedgehog.utils import protobuf
from ..proto import hedgehog_pb2


class Message(protobuf.Message):
    async = False

    @classmethod
    def msg_name(cls):
        module, name = cls.__module__, cls.__name__
        module = module[module.rindex('.') + 1:]
        return module + '.' + name

    def __repr__(self):
        field_pairs = ((field, getattr(self, field)) for field in self.meta.fields)
        field_reprs = ('{}={}'.format(field, repr(value)) for field, value in field_pairs)
        return '{}({})'.format(self.msg_name(), ', '.join(field_reprs))


class SimpleMessage(Message, protobuf.SimpleMessageMixin):
    pass


class ContainerMessage(protobuf.ContainerMessage):
    def parse(self, data: bytes) -> Message:
        return cast(Message, super(ContainerMessage, self).parse(data))


RequestMsg = ContainerMessage(hedgehog_pb2.HedgehogMessage)
ReplyMsg = ContainerMessage(hedgehog_pb2.HedgehogMessage)



"""A setuptools based setup module.

See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='hedgehog-protocol',
    version='0.5.0',
    description='Protocol definitions for Hedgehog',
    long_description=long_description,
    url="https://github.com/PRIArobotics/HedgehogProtocol",
    author="Clemens Koza",
    author_email="koza@pria.at",
    license="AGPLv3+",

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Software Development',
        'License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)',
        'Programming Language :: Python :: 3',
    ],

    keywords='hedgehog robotics protobuf zmq protocol',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=['hedgehog-utils[protobuf,zmq]'],

    # You can install these using the following syntax, for example:
    # $ pip install -e .[dev,test]
    extras_require={
        'dev': ['invoke'],
    },

    package_data={
        'proto': ['*.proto'],
    },

    entry_points={
        'console_scripts': [
        ],
    },
)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hedgehog/protocol/proto/servo.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hedgehog.protocol.proto import subscription_pb2 as hedgehog_dot_protocol_dot_proto_dot_subscription__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hedgehog/protocol/proto/servo.proto',
  package='hedgehog.protocol.proto',
  syntax='proto3',
  serialized_pb=_b('\n#hedgehog/protocol/proto/servo.proto\x12\x17hedgehog.protocol.proto\x1a*hedgehog/protocol/proto/subscription.proto\"=\n\x0bServoAction\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\x0e\n\x06\x61\x63tive\x18\x02 \x01(\x08\x12\x10\n\x08position\x18\x03 \x01(\r\"\x82\x01\n\x13ServoCommandMessage\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\x0e\n\x06\x61\x63tive\x18\x02 \x01(\x08\x12\x10\n\x08position\x18\x03 \x01(\r\x12;\n\x0csubscription\x18\x04 \x01(\x0b\x32%.hedgehog.protocol.proto.SubscriptionB)\n\x1f\x61t.pria.hedgehog.protocol.protoB\x06ServoPb\x06proto3')
  ,
  dependencies=[hedgehog_dot_protocol_dot_proto_dot_subscription__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_SERVOACTION = _descriptor.Descriptor(
  name='ServoAction',
  full_name='hedgehog.protocol.proto.ServoAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.ServoAction.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='active', full_name='hedgehog.protocol.proto.ServoAction.active', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position', full_name='hedgehog.protocol.proto.ServoAction.position', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=169,
)


_SERVOCOMMANDMESSAGE = _descriptor.Descriptor(
  name='ServoCommandMessage',
  full_name='hedgehog.protocol.proto.ServoCommandMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.ServoCommandMessage.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='active', full_name='hedgehog.protocol.proto.ServoCommandMessage.active', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position', full_name='hedgehog.protocol.proto.ServoCommandMessage.position', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subscription', full_name='hedgehog.protocol.proto.ServoCommandMessage.subscription', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=302,
)

_SERVOCOMMANDMESSAGE.fields_by_name['subscription'].message_type = hedgehog_dot_protocol_dot_proto_dot_subscription__pb2._SUBSCRIPTION
DESCRIPTOR.message_types_by_name['ServoAction'] = _SERVOACTION
DESCRIPTOR.message_types_by_name['ServoCommandMessage'] = _SERVOCOMMANDMESSAGE

ServoAction = _reflection.GeneratedProtocolMessageType('ServoAction', (_message.Message,), dict(
  DESCRIPTOR = _SERVOACTION,
  __module__ = 'hedgehog.protocol.proto.servo_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.ServoAction)
  ))
_sym_db.RegisterMessage(ServoAction)

ServoCommandMessage = _reflection.GeneratedProtocolMessageType('ServoCommandMessage', (_message.Message,), dict(
  DESCRIPTOR = _SERVOCOMMANDMESSAGE,
  __module__ = 'hedgehog.protocol.proto.servo_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.ServoCommandMessage)
  ))
_sym_db.RegisterMessage(ServoCommandMessage)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\037at.pria.hedgehog.protocol.protoB\006ServoP'))
# @@protoc_insertion_point(module_scope)
